@@ -27,7 +27,6 @@ from typing import (
     TypeVar,
     Union,
     cast,
-    get_args,
 )
 from uuid import NAMESPACE_DNS, UUID, uuid1, uuid3, uuid4, uuid5
 
@@ -77,7 +76,7 @@ from pydantic import (
 )
 from pydantic.color import Color
 from pydantic.fields import ModelField
-from typing_extensions import Type
+from typing_extensions import Type, get_args
 
 from pydantic_factories.constraints.constrained_collection_handler import (
     handle_constrained_collection,
@@ -108,6 +107,7 @@ from pydantic_factories.protocols import (
 )
 from pydantic_factories.utils import (
     create_model_from_dataclass,
+    is_literal,
     is_optional,
     is_pydantic_model,
 )
@@ -380,7 +380,7 @@ class ModelFactory(ABC, Generic[T]):
             return cls.handle_constrained_field(model_field=model_field)
         if model_field.sub_fields:
             return handle_complex_type(model_field=model_field, model_factory=cls)
-        if "typing.Literal" in repr(outer_type):
+        if is_literal(model_field):
             return get_args(outer_type)[0]
         # this is a workaround for the following issue: https://github.com/samuelcolvin/pydantic/issues/3415
         field_type = model_field.type_ if model_field.type_ is not Any else outer_type
@@ -427,8 +427,15 @@ class ModelFactory(ABC, Generic[T]):
         return model.__fields__.items()  # type: ignore
 
     @classmethod
-    def build(cls, **kwargs) -> T:
-        """builds an instance of the factory's Meta.model"""
+    def build(cls, factory_use_construct: bool = False, **kwargs) -> T:
+        """
+        builds an instance of the factory's __model__
+
+        If factory_use_construct is True, then no validations will be made when instantiating the model,
+        see: https://pydantic-docs.helpmanual.io/usage/models/#creating-models-without-validation.
+
+        Note - this is supported only for pydantic models
+        """
         for field_name, model_field in cls.get_model_fields(cls._get_model()):
             if model_field.alias:
                 field_name = model_field.alias
@@ -437,6 +444,10 @@ class ModelFactory(ABC, Generic[T]):
                     kwargs[field_name] = cls.handle_factory_field(field_name=field_name)
                 else:
                     kwargs[field_name] = cls.get_field_value(model_field=model_field)
+        if factory_use_construct:
+            if is_pydantic_model(cls.__model__):
+                return cls.__model__.construct(**kwargs)  # type: ignore
+            raise ConfigurationError("factory_use_construct requires a pydantic model as the factory's __model__")
         return cls.__model__(**kwargs)
 
     @classmethod
